# 8th IAS Conference on HIV Pathogenesis, Treatment & Prevention 19–22 July 2015, Vancouver, Canada

**Authors:** Pate, Pohlmeyer, Walker-Sperling, Foote, Najarro, Cryer, Salgado, Gama, Engle, Shirk, Queen, Chioma, Vermillion, Bullock, Li, Lyons, Adams, Zink, Clements, Mankowski, Blankson, Micci, Ryan, Fromentin, Benne, Chomont, Lifson, Paiardini, Lee, Chomont, Fromentin, Silicano, Silicano, Richman, O’Doherty, Palmer, Burbelo, Deeks, Ghneim, Ahlers, Fourati, Shive, Cameron, Mukerjee, Ghannoum, Rodriguez, Lederman, Sékaly, Frange, Faye, Avettand-Fenoel, Bellaton, Deschamps, Angin, Caillat-Zucman, Peytavin, Chenadec, Warszawski, Rouzioux, Sáez-Cirión, Chang, Cameron, Elliott, Perelson, Roche, Dantanarayana, Solomon, Naranbhai, Tenakoon, Hoh, McMahon, Sikaris, Hartogensis, Bacchetti, Hecht, Lifson, Deeks, Lewin, Byrareddy, Arthos, Cicala, Reimann, Parslow, Santangelo, Villinger, Fauci, Ansari, George, Weiser, Burger, Lewy, Anastos, Asmuth, Somsouk, Hunt, Ma, Miller, Li, Hinkle, Shaw, Weaver, Klein, Viljoen, Wendoh, Karaoz, Brodie, Mulder, Botha, Kidzeru, Butcher, Gray, Rosenthal, Abimiku, Cameron, Stintzi, Jaspan, Schafer, Evans, Li, Reeves, Kroon, Dunning, Hsiao, Myer, Crowell, Maiga, Sylla, Taiwo, Koné, Murphy, Marcelin, Traore, Fofana, Chadwick, Ásbjörnsdóttir, Slyker, Wamalwa, Rosa, Hughes, Rowhani-Rahbar, Chohan, Benki-Nugent, Tapia, John-Stewart, Kizito, Gaur, Prasitsuebsai, Rakhmanina, Chokephaibulkit, Fourie, Bekker, Shao, Bennett, Quirk, Prasitsuebsai, Teeraananchai, Truong, Ananworanich, Do, Nguyen, Kosalaraksa, Kurniati, Sudjaritruk, Chokephaibulkit, Singtoroj, Kerr, Sohn, Lombaard, Bunupuradah, Flynn, Ramapuram, Ssali, Crauwels, Hoogstoel, Eygen, Stevens, Boven, Jao, Myer, Phillips, Petro, Zerbe, Abrams, Hanrahan, Martinson, Link‐Barnes, Msandiwa, Chaisson, Golub, Evans, Schnippel, Budgell, Shearer, Berhanu, Long, Rosen, Schultze, Efsen, Post, Panteleev, Furrer, Miller, Losso, Toibaro, Skrahin, Miro, Caylà, Girardi, Bruyand, Obel, Podlekareva, Lundgren, Mocroft, Kirk, Baddeley, Doherty, Kanchar, Matteelli, Timimi, Getahun, Hosseinipour, Bisson, Miyahara, Sun, Moses, Riviere, Kirui, Badal-Faesen, Lagat, Nyirenda, Naidoo, Hakim, Mugyenyi, Henostroza, Leger, Lama, Mohapi, Alave, Mave, Veloso, Pillay, Kumarasamy, Bao, Hogg, Jones, Zolopa, Kumwenda, Gupta, Cohen, Chen, McCauley, Gamble, Hosseinipour, Kumarasamy, Hakim, Kumwenda, Brum, Grinsztejn, Godbole, Chariyalertsak, Santos, Mayer, Hoffman, Eshleman, Piwowar-Manning, Ou, Cottle, Makhema, Mills, Panchia, Badal-Faesen, Eron, Gallant, Havlir, Swindells, Elharrar, Burns, Taha, Nielsen, Celentano, Essex, Fleming, Jean, Puren, Cutler, Singh, Bouscaillou, Rain-Taljaard, Taljjard, Lissouba, Peytavin, Auvert, Jenkins, Nordio, Vasarhelyi, Núñez, Barrios, Rutherford, Iwuji, Dray-Spira, Calmy, Larmarange, Orne-Gliemann, Dabis, Pillay, Porter, Barnabas, Rooyen, Tumwesigye, Brantley, Baeten, Heerden, Turyamureeba, Joseph, Krows, Hughes, Celum, Eshleman, Hudelson, Ou, Redd, Swanstrom, Porcella, Chen, McCauley, Gamble, Sievers, Martens, Bruno, Ping, Dukhovlinova, Quinn, Kumwenda, Maliwichi, Nhando, Akelo, Moyo, Panchia, Kumarasamy, Chotirosniramit, Rocha, Bustorff, Grinsztejn, Mayer, Hughes, Cohen, Haas, Tenthani, Msukwa, Jahn, Midiani, Mhango, Gadabu, Tal, Spörri, Egger, Chimbwandira, Oosterhout, Keiser, Rosenberg, Mtande, Saidi, Stanley, Jere, Mwangomba, Kumwenda, Mofolo, Mwale, Chauma, Miller, Hoffman, Hosseinipour, Buzdugan, McCoy, Watadzaushe, Dufour, Petersen, Dirawo, Mushavi, Mujuru, Mahomva, Engelsmann, Hakobyan, Mugurungi, Cowan, Padian, Lallemant, Amzal, Urien, Sripan, Cressey, Ngo-Giang-Huong, Rawangban, Sabsanong, Siriwachirachai, Jarupanich, Kanjanavikai, Wanasiri, Koetsawang, Jourdain, Cœur, Ochoa‐Moreno, Mangenah, Buzdugan, Padian, McCoy, Cowan, Bautista-Arredondo, Wambura, Hayes, Grund, Kapiga, Mahler, Mshana, Kuringe, Plotkin, Bock, Larke, Changalucha, Weiss, Thirumurthy, Akello, Murray, Masters, Maman, Omanga, Agot, Duwve, Hoover, Conrad, Galang, Hillman, Hoots, Patel, Peters, Pontones, Roseberry, Shields, Waterhouse, Weidle, Galang, Gentry, Peters, Blosser, Chapman, Duwve, Ganova-Raeva, Heneine, Jia, Liu, Luo, Lovchik, Masciotra, Owen, Perez, Peyrani, Ramachandran, Roseberry, Sandoval, Shankar, Thai, Xia, Khudyakov, Switzer, Mannheimer, Hirsch-Moverman, Loquere, Franks, Hughes, Amico, Hendrix, Dye, Piwowar-Manning, Marzinke, Elharrar, Stirratt, Grant, Holtz, Chitwarakorn, Curlin, Anderson, Eshleman, Grant, Doherty, Beusenberg, Asamoah-odei, Lule, Pendse, Ghidinelli, Lo, Reidner, Donoghoe, Vitoria, Hirnschall, Levi, Raymond, Pozniak, Vernazza, Kohler, Ford
**Year:** 2015
**DOI:** 10.7448/IAS.18.5.20479
**URL:** https://doi.org/10.7448/IAS.18.5.20479

## Abstract

Sensitive assays are needed for detection of residual HIV in patients with undetectable plasma viral loads to determine if eradication strategies are effective. The gold standard quantitative viral outgrowth assay (QVOA) underestimates the magnitude of the viral reservoir, while sensitive PCR‐based assays lack the ability to distinguish replication competent from defective virus. We sought to determine whether xenograft of leukocytes from HIV‐1 infected patients with undetectable plasma viral loads into severely immunocompromised mice would result in viral amplification and measurable viral loads within the aberrant murine host.

## Citation Details

8th IAS Conference on HIV Pathogenesis, Treatment & Prevention 19–22 July 2015, Vancouver, Canada
**Authors**: Pate, Pohlmeyer, Walker-Sperling, Foote, Najarro, Cryer, Salgado, Gama, Engle, Shirk, Queen, Chioma, Vermillion, Bullock, Li, Lyons, Adams, Zink, Clements, Mankowski, Blankson, Micci, Ryan, Fromentin, Benne, Chomont, Lifson, Paiardini, Lee, Chomont, Fromentin, Silicano, Silicano, Richman, O’Doherty, Palmer, Burbelo, Deeks, Ghneim, Ahlers, Fourati, Shive, Cameron, Mukerjee, Ghannoum, Rodriguez, Lederman, Sékaly, Frange, Faye, Avettand-Fenoel, Bellaton, Deschamps, Angin, Caillat-Zucman, Peytavin, Chenadec, Warszawski, Rouzioux, Sáez-Cirión, Chang, Cameron, Elliott, Perelson, Roche, Dantanarayana, Solomon, Naranbhai, Tenakoon, Hoh, McMahon, Sikaris, Hartogensis, Bacchetti, Hecht, Lifson, Deeks, Lewin, Byrareddy, Arthos, Cicala, Reimann, Parslow, Santangelo, Villinger, Fauci, Ansari, George, Weiser, Burger, Lewy, Anastos, Asmuth, Somsouk, Hunt, Ma, Miller, Li, Hinkle, Shaw, Weaver, Klein, Viljoen, Wendoh, Karaoz, Brodie, Mulder, Botha, Kidzeru, Butcher, Gray, Rosenthal, Abimiku, Cameron, Stintzi, Jaspan, Schafer, Evans, Li, Reeves, Kroon, Dunning, Hsiao, Myer, Crowell, Maiga, Sylla, Taiwo, Koné, Murphy, Marcelin, Traore, Fofana, Chadwick, Ásbjörnsdóttir, Slyker, Wamalwa, Rosa, Hughes, Rowhani-Rahbar, Chohan, Benki-Nugent, Tapia, John-Stewart, Kizito, Gaur, Prasitsuebsai, Rakhmanina, Chokephaibulkit, Fourie, Bekker, Shao, Bennett, Quirk, Prasitsuebsai, Teeraananchai, Truong, Ananworanich, Do, Nguyen, Kosalaraksa, Kurniati, Sudjaritruk, Chokephaibulkit, Singtoroj, Kerr, Sohn, Lombaard, Bunupuradah, Flynn, Ramapuram, Ssali, Crauwels, Hoogstoel, Eygen, Stevens, Boven, Jao, Myer, Phillips, Petro, Zerbe, Abrams, Hanrahan, Martinson, Link‐Barnes, Msandiwa, Chaisson, Golub, Evans, Schnippel, Budgell, Shearer, Berhanu, Long, Rosen, Schultze, Efsen, Post, Panteleev, Furrer, Miller, Losso, Toibaro, Skrahin, Miro, Caylà, Girardi, Bruyand, Obel, Podlekareva, Lundgren, Mocro  # Truncate if very long

---
*Extracted from citation research database - all 51 citations available*
